%if 0%{?fedora} >= 22
%global with_python3 1
%endif

%define author mgaitan
%define unmangled_name waliki
%define unmangled_version 0.6

Summary: An extensible wiki app for Django with a Git backend
Name: python-django-%{unmangled_name}
Version: %{unmangled_version}
Release: 3%{?dist}.7
Source0: https://github.com/%{author}/%{unmangled_name}/archive/%{version}/%{unmangled_name}-%{version}.tar.gz
Patch0: waliki-0.6-sh-out-nopipe.patch
License: BSD
Group: Development/Libraries
Prefix: %{_prefix}
BuildArch: noarch
Vendor: Martín Gaitán <gaitan@gmail.com>
Url: https://github.com/mgaitan/waliki
BuildRequires: python2-devel
BuildRequires: python-setuptools
BuildRequires: python-django >= 1.5.1
BuildRequires: python-markups
BuildRequires: python-sh
BuildRequires: python-docutils
BuildRequires: python-rst2html5
BuildRequires: python-pyquery
BuildRequires: python-django-nose
BuildRequires: python-factory-boy
BuildRequires: python-fake-factory
BuildRequires: python-markdown
BuildRequires: python-django-sendfile
BuildRequires: python-mock
BuildRequires: hovercraft
%if 0%{?with_python3}
BuildRequires: python3-devel
BuildRequires: python3-setuptools
BuildRequires: python3-django >= 1.5.1
BuildRequires: python3-markups
BuildRequires: python3-sh
BuildRequires: python3-docutils
BuildRequires: python3-rst2html5
BuildRequires: python3-pyquery
BuildRequires: python3-django-nose
BuildRequires: python3-factory-boy
BuildRequires: python3-fake-factory
BuildRequires: python3-markdown
BuildRequires: python3-django-sendfile
BuildRequires: python3-mock
%endif
Requires: python-django
Requires: python-markups
Requires: python-sh
Requires: python-docutils
Requires: python-rst2html5
Requires: python-pyquery
Requires: python-micawber >= 0.3.0
Requires: python-markdown
Requires: python-django-sendfile
Requires: rst2pdf
Requires: hovercraft

%description
Waliki is an extensible wiki app for Django with a Git backend.

At a glance, Waliki has these features:

* File based content storage.
* UI based on Bootstrap and CodeMirror
* Version control and concurrent edition for your content using git
* An extensible architecture through plugins
* reStructuredText or Markdown support, configurable per page
  (and it's easy to add extensions)
* A very simple *per slug* ACL system
* A nice attachments manager (that respects the permissions over the page)
* Realtime collaborative edition via togetherJS
* Wiki content embeddable in any django template (as a "dummy CMS")
* Few helpers to migrate content (particularly from MoinMoin, using moin2git)
* It works with Python 2.7, 3.3, 3.4 or PyPy in Django 1.6 or newer

It's easy to create a site powered by Waliki using the preconfigured project
which is the same code that motorize the demo.

Waliki was inspired in Github's wikis, but it tries to be a bit smarter
than many others git backed wiki engines at handling changes:
instead of a hard "newer wins" or "page blocking" approaches,
Waliki uses git's merge facilities on each save.
So, if there was another change during an edition and git can merge them
automatically, it's done and the user is notified.
If the merge fails, the last edition is still saved but the editor is
reloaded asking the user to fix the conflict.

%if 0%{?with_python3}
%package -n python3-django-%{unmangled_name}
Summary: An extensible wiki app for Django with a Git backend
Group: Development/Libraries
Requires: python3-django
Requires: python3-markups
Requires: python3-sh
Requires: python3-docutils
Requires: python3-rst2html5
Requires: python3-pyquery
Requires: python3-micawber >= 0.3.0
Requires: python3-markdown
Requires: python3-django-sendfile
Requires: rst2pdf
Requires: hovercraft

%description -n python3-django-%{unmangled_name}
Waliki is an extensible wiki app for Django with a Git backend.

At a glance, Waliki has these features:

* File based content storage.
* UI based on Bootstrap and CodeMirror
* Version control and concurrent edition for your content using git
* An extensible architecture through plugins
* reStructuredText or Markdown support, configurable per page
  (and it's easy to add extensions)
* A very simple *per slug* ACL system
* A nice attachments manager (that respects the permissions over the page)
* Realtime collaborative edition via togetherJS
* Wiki content embeddable in any django template (as a "dummy CMS")
* Few helpers to migrate content (particularly from MoinMoin, using moin2git)
* It works with Python 2.7, 3.3, 3.4 or PyPy in Django 1.6 or newer

It's easy to create a site powered by Waliki using the preconfigured project
which is the same code that motorize the demo.

Waliki was inspired in Github's wikis, but it tries to be a bit smarter
than many others git backed wiki engines at handling changes:
instead of a hard "newer wins" or "page blocking" approaches,
Waliki uses git's merge facilities on each save.
So, if there was another change during an edition and git can merge them
automatically, it's done and the user is notified.
If the merge fails, the last edition is still saved but the editor is
reloaded asking the user to fix the conflict.

This package contains the python3 version of this module.
%endif

%prep
%setup -n %{unmangled_name}-%{version}
%patch0 -p1

%if 0%{?with_python3}
rm -rf %{py3dir}
cp -a . %{py3dir}
pushd %{py3dir}
popd
%endif

%build
%{__python2} setup.py build

%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py build
popd
%endif

%install
%{__python2} setup.py install \
  --skip-build \
  --single-version-externally-managed \
  -O2 \
  --root=$RPM_BUILD_ROOT \
  --record=INSTALLED_FILES_PY2

%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py install \
  --skip-build \
  --single-version-externally-managed \
  -O2 \
  --root=$RPM_BUILD_ROOT \
  --record="%{_builddir}/%{buildsubdir}/INSTALLED_FILES_PY3"
popd
%endif

%check
LANG=en_US.UTF-8 %{__python2} runtests.py

%if 0%{?with_python3}
pushd %{py3dir}
LANG=en_US.UTF-8 %{__python3} runtests.py
popd
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%files -f INSTALLED_FILES_PY2
%defattr(-,root,root)

%if 0%{?with_python3}
%files -n python3-django-%{unmangled_name} -f INSTALLED_FILES_PY3
%defattr(-,root,root)
%endif
%changelog
* Sat Nov 14 2015 Oleg Girko <ol@infoserver.lv> 0.6-2
- Enable build with Python 3
- Improve patch to run commands with output to pipe with some missed cases
* Fri Nov 13 2015 Oleg Girko <ol@infoserver.lv> 0.6-1
- Update to version 0.6
* Fri Sep 11 2015 Oleg Girko <ol@infoserver.lv> 0.6~0.1.20150608.git165d86-2
- Run proper tests
* Thu Sep 10 2015 Oleg Girko <ol@infoserver.lv> 0.6~0.1.20150608.git165d86-1
- Initial package
